package api

import (
	"errors"
	"moutai/db/model"
	"moutai/db/repo"
	"moutai/log"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func CreateImage(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	Image := &model.Images{}
	err := c.ShouldBindJSON(&Image)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	defuealt := 0
	Image.Clicks = &defuealt
	Image.Sort = &defuealt

	// 正常状态
	state := -1
	Image.State = &state
	Image.CreateTime = time.Now()
	Image.UpdateTime = time.Now()
	return repo.RepoAddDoc(apictx.CreateRepoCtx(), repo.CollectionImages, &Image)
}

func DeleteImage(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoDeleteDoc(apictx.CreateRepoCtx(), repo.CollectionImages, _id)
}

func ImageList(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	page, size, query := UtilQueryPageSize(c)
	query, sort := getQuery(query)
	result, err := repo.RepoPageSearch(apictx.CreateRepoCtx(), &repo.PageSearchOptions{
		CollectName: repo.CollectionImages,
		Page:        page,
		Size:        size,
		Query:       query,
		Sort:        sort,
	})

	cate := model.Catgory{}
	if len(result.List) > 0 {
		for i, u := range result.List {
			if v, ok := u["cid"]; ok {
				// 查询角色信息
				cid := v.(primitive.ObjectID)
				repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
					CollectName: repo.CollectionCategories,
					Query:       repo.Map{"_id": cid},
				}, &cate)
			}
			// 拼接角色信息
			result.List[i]["cateInfo"] = cate
		}
	}
	return result, err
}

func UpdateImage(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	Image := &model.Images{}
	err := c.ShouldBindJSON(&Image)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	if Image.Id.IsZero() {
		return nil, errors.New("id错误")
	}

	Image.UpdateTime = time.Now()
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionImages, Image.Id.Hex(), Image)
}

func ImageOn(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	state := 1
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionImages, _id, model.Images{State: &state})
}

func ImageOff(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	state := -1
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionImages, _id, model.Images{State: &state})
}
