package api

import (
	"errors"
	"moutai/db/model"
	"moutai/db/repo"
	"moutai/log"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func CreateRelic(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	Relic := &model.Relics{}
	err := c.ShouldBindJSON(&Relic)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	defuealt := 0
	Relic.Clicks = &defuealt
	Relic.Sort = &defuealt
	// 正常状态
	state := -1
	Relic.State = &state
	Relic.CreateTime = time.Now()
	Relic.UpdateTime = time.Now()
	return repo.RepoAddDoc(apictx.CreateRepoCtx(), repo.CollectionRelics, &Relic)
}

func DeleteRelic(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoDeleteDoc(apictx.CreateRepoCtx(), repo.CollectionRelics, _id)
}

func RelicList(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	page, size, query := UtilQueryPageSize(c)
	query, sort := getQuery(query)
	result, err := repo.RepoPageSearch(apictx.CreateRepoCtx(), &repo.PageSearchOptions{
		CollectName: repo.CollectionRelics,
		Page:        page,
		Size:        size,
		Query:       query,
		Sort:        sort,
	})

	cate := model.Catgory{}
	if len(result.List) > 0 {
		for i, u := range result.List {
			if v, ok := u["cid"]; ok {
				// 查询角色信息
				cid := v.(primitive.ObjectID)
				repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
					CollectName: repo.CollectionCategories,
					Query:       repo.Map{"_id": cid},
				}, &cate)
			}
			// 拼接角色信息
			result.List[i]["cateInfo"] = cate
		}
	}
	return result, err
}

func UpdateRelic(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	Relic := &model.Relics{}
	err := c.ShouldBindJSON(&Relic)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	if Relic.Id.IsZero() {
		return nil, errors.New("id错误")
	}

	Relic.UpdateTime = time.Now()
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionRelics, Relic.Id.Hex(), Relic)
}

func RelicOn(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	state := 1
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionRelics, _id, model.Relics{State: &state})
}

func RelicOff(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	state := -1
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionRelics, _id, model.Relics{State: &state})
}
